## recipemd-extract

recipemd-extract extracts recipes from websites and saves them in the [recipemd](https://github.com/tstehr/recipemd/blob/master/specification.md) format. It is based on [recipemd-cli](https://github.com/dnlvgl/recipemd-cli).

## installation

`pip install recipemd-extract`

## usage

`recipemd-extract 'url-of-recipe'`

## supported websites

1. chefkoch.de
2. seriouseats.com
3. Any Wordpress blog using [WP Recipe Manager](https://en-ca.wordpress.org/plugins/wp-recipe-manager/)
4. Any page supporting [recipe schema](https://schema.org/Recipe)
5. Any page supported by [recipe-scrapers](https://github.com/hhursev/recipe-scrapers)


